@@ -1,20 +1,3 @@
-// XDrawChem
-// Copyright (C) 2004-2005  Bryan Herger <bherger@users.sourceforge.net>
-// Copyright (C) 2020  Yaman Qalieh <ybq987@gmail.com>
-
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version.
-
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <https://www.gnu.org/licenses/>.
-
 #ifndef DEFS_H
 #define DEFS_H
 
@@ -23,7 +6,7 @@
 // Ring directories (global, user)
 extern QString RingDir, HomeDir;
 
-const QString VERSION = QString::fromLatin1("1.11.0");
+const QString VERSION = QString::fromLatin1("1.99.1");
 
 // version string (makes updates easier :)
 #ifdef UNIX
@@ -38,8 +21,8 @@ const QString XDC_VERSION = QString::fromLatin1("WinDrawChem ") + VERSION;
 const QString XDC_VERSION = QString::fromLatin1("MacDrawChem ") + VERSION;
 #endif
 
-// define XDC_SERVER default URL
-//#define XDC_SERVER "http://www.woodsidelabs.com/chemistry"
+// define XDC_SERVER for Windows
+#define XDC_SERVER "www.xdrawchem.org"
 
 // units
 #define PIXELS 0
@@ -53,7 +36,7 @@ const QString XDC_VERSION = QString::fromLatin1("MacDrawChem ") + VERSION;
 
 // math constant
 #define MOL_ARAD 57.29578
-#ifndef M_PI // M_PI is usually defined on Unix, but not Windows
+#ifndef UNIX  // M_PI is usually defined on Unix, but not Windows
 #define M_PI 3.14159246
 #endif
 
@@ -80,22 +63,22 @@ const QString XDC_VERSION = QString::fromLatin1("MacDrawChem ") + VERSION;
 #define MODE_DRAWLINE_DASH 210
 #define MODE_DRAWLINE_DASH_DRAWING 211
 
-#define MODE_DRAWLINE_UP 220
+#define MODE_DRAWLINE_UP  220
 #define MODE_DRAWLINE_UP_DRAWING 221
 
-#define MODE_DRAWLINE_DOWN 240
+#define MODE_DRAWLINE_DOWN  240
 #define MODE_DRAWLINE_DOWN_DRAWING 241
 
-#define MODE_DRAWWAVYLINE 250
+#define MODE_DRAWWAVYLINE  250
 #define MODE_DRAWWAVYLINE_DRAWING 251
 
-#define MODE_DRAWARROW 260
+#define MODE_DRAWARROW  260
 #define MODE_DRAWARROW_DRAWING 261
 
 #define MODE_DRAWCURVEARROW 270
 #define MODE_DRAWCURVEARROW_DRAWING 271
 
-#define MODE_DRAWBRACKET 280
+#define MODE_DRAWBRACKET  280
 #define MODE_DRAWBRACKET_DRAWING 281
 
 #define MODE_DRAWBEZIER 290
@@ -117,9 +100,9 @@ const QString XDC_VERSION = QString::fromLatin1("MacDrawChem ") + VERSION;
 #define MODE_TOOL_CALCEF 602
 #define MODE_TOOL_13CNMR 603
 #define MODE_TOOL_CALCEA 604
-#define MODE_TOOL_1HNMR 605
-#define MODE_TOOL_IR 606
-#define MODE_TOOL_NAME 607
+#define MODE_TOOL_1HNMR  605
+#define MODE_TOOL_IR     606
+#define MODE_TOOL_NAME   607
 #define MODE_TOOL_TOSMILES 608
 #define MODE_TOOL_FROMSMILES 609
 #define MODE_TOOL_CLEANUPMOL 610
@@ -186,13 +169,13 @@ enum bracketType {
 };
 
 // bracket types (Bracket::style)
-#define BRACKET_SQUARE 1
-#define BRACKET_CURVE 2
-#define BRACKET_BRACE 3
-#define BRACKET_BOX 4
+#define BRACKET_SQUARE  1
+#define BRACKET_CURVE   2
+#define BRACKET_BRACE   3
+#define BRACKET_BOX     4
 #define BRACKET_ELLIPSE 5
-#define BRACKET_CLOSEDSQUARE 6
-#define BRACKET_CIRCLE 7
+#define BRACKET_CLOSEDSQUARE  6
+#define BRACKET_CIRCLE  7
 #define BRACKET_BOX_SHADOW 8
 #define BRACKET_ELLIPSE_SHADOW 9
 #define BRACKET_SQUARE_SHADOW 10
@@ -306,10 +289,11 @@ enum symbolType {
 #define GROUP_CATALYST 4
 
 // output devices
-#define OUTPUT_SCREEN 1
-#define OUTPUT_IMAGE 2
+#define OUTPUT_SCREEN  1
+#define OUTPUT_IMAGE   2
 #define OUTPUT_PRINTER 3
-#define OUTPUT_EPS 4
+#define OUTPUT_EPS     4
+#define OUTPUT_SVG     5
 
 // Paintable::op Operation types
 /*  OBSOLETE
@@ -330,30 +314,32 @@ enum symbolType {
 
 // page setup
 #define PAGE_LETTER 1
-#define PAGE_LEGAL 2
-#define PAGE_A4 3
-#define PAGE_640 4
-#define PAGE_800 5
-#define PAGE_1024 6
+#define PAGE_LEGAL  2
+#define PAGE_A4     3
+#define PAGE_640    4
+#define PAGE_800    5
+#define PAGE_1024   6
 #define PAGE_CUSTOM 7
-#define PAGE_PORTRAIT 100
+#define PAGE_PORTRAIT  100
 #define PAGE_LANDSCAPE 200
 
 // CML stuff
 // track what tag(s) we're in (private int CMLParser::states)
 #define CML_MOLECULE 10
-#define CML_NONE 1
-#define CML_ATOM 2
-#define CML_BOND 3
+#define CML_NONE   1
+#define CML_ATOM   2
+#define CML_BOND   3
 #define CML_ATOMARRAY 4
 #define CML_BONDARRAY 5
-#define CDXML_COLORTABLE 100
-#define CDXML_FONTTABLE 101
-#define CDXML_PAGE 102
-#define CDXML_FRAGMENT 103
-#define CDXML_NODE 104
-#define CDXML_BOND 105
-#define CDXML_GRAPHIC 106
-#define CDXML_TEXT 107
+#define CDXML_COLORTABLE  100
+#define CDXML_FONTTABLE   101
+#define CDXML_PAGE        102
+#define CDXML_FRAGMENT    103
+#define CDXML_NODE        104
+#define CDXML_BOND        105
+#define CDXML_GRAPHIC     106
+#define CDXML_TEXT        107
 
 #endif // ifndef DEFS_H
+
+// kate: tab-width 4; indent-width 4; space-indent on; replace-trailing-space-save on;
