@@ -1,7 +1,7 @@
 #include "xdc_toolbutton.h"
 
 XDC_ToolButton::XDC_ToolButton(QWidget *parent, QString name) :
-  QToolButton(parent, name) {
+  QToolButton() {
   fn = name;
 }
 
